@@ -36,6 +36,7 @@ pub trait Signer: std::fmt::Debug + Send + Sync {
 mod tests {
     use fuel_crypto::{Message, SecretKey};
     use fuel_tx::{AssetId, Bytes32, Input, Output, UtxoId};
+    use fuels_core::parameters::TxParameters;
     use fuels_test_helpers::{setup_address_and_coins, setup_test_client};
     use rand::{rngs::StdRng, RngCore, SeedableRng};
     use std::str::FromStr;
@@ -130,12 +131,12 @@ mod tests {
     #[tokio::test]
     async fn send_transaction() {
         // Setup two sets of coins, one for each wallet, each containing 1 coin with 1 amount.
-        let (pk_1, mut coins_1) = setup_address_and_coins(1, 1);
-        let (pk_2, coins_2) = setup_address_and_coins(1, 1);
+        let (pk_1, mut coins_1) = setup_address_and_coins(1, 1000000);
+        let (pk_2, coins_2) = setup_address_and_coins(1, 1000000);
 
         coins_1.extend(coins_2);
 
-        // Setup a provider and node with both set of coins
+        // Setup a provider and node with both set of coins.
         let (client, _) = setup_test_client(coins_1).await;
         let provider = Provider::new(client);
 
@@ -145,26 +146,56 @@ mod tests {
         let wallet_1_initial_coins = wallet_1.get_coins().await.unwrap();
         let wallet_2_initial_coins = wallet_2.get_coins().await.unwrap();
 
-        // Check initial wallet state
+        // Check initial wallet state.
         assert_eq!(wallet_1_initial_coins.len(), 1);
         assert_eq!(wallet_2_initial_coins.len(), 1);
 
-        // Transfer 1 from wallet 1 to wallet 2
-        let _receipts = wallet_1
-            .transfer(&wallet_2.address(), 1, Default::default())
+        // Configure transaction parameters.
+        let gas_price = 1;
+        let gas_limit = 500_000;
+        let byte_price = 1;
+        let maturity = 0;
+
+        let tx_params = TxParameters {
+            gas_price,
+            gas_limit,
+            byte_price,
+            maturity,
+        };
+
+        // Transfer 1 from wallet 1 to wallet 2.
+        let (tx_id, _receipts) = wallet_1
+            .transfer(&wallet_2.address(), 1, Default::default(), tx_params)
             .await
             .unwrap();
 
-        // Currently ignoring the effect on wallet 1, as coins aren't being marked as spent for now
+        // Assert that the transaction was properly configured.
+        let res = wallet_1
+            .provider
+            .get_transaction_by_id(&tx_id)
+            .await
+            .unwrap();
+
+        assert_eq!(res.transaction.byte_price(), byte_price);
+        assert_eq!(res.transaction.gas_limit(), gas_limit);
+        assert_eq!(res.transaction.gas_price(), gas_price);
+        assert_eq!(res.transaction.maturity(), maturity);
+
+        // Currently ignoring the effect on wallet 1, as coins aren't being marked as spent for now.
         let _wallet_1_final_coins = wallet_1.get_coins().await.unwrap();
         let wallet_2_final_coins = wallet_2.get_coins().await.unwrap();
 
-        // Check that wallet two now has two coins
+        // Check that wallet two now has two coins.
         assert_eq!(wallet_2_final_coins.len(), 2);
 
-        // Transferring more than balance should fail
+        // Transferring more than balance should fail.
         let result = wallet_1
-            .transfer(&wallet_2.address(), 2, Default::default())
+            .transfer(
+                &wallet_2.address(),
+                2000000,
+                Default::default(),
+                TxParameters::default(),
+            )
             .await;
 
         assert!(result.is_err());
@@ -194,7 +225,12 @@ mod tests {
 
         // Transfer 2 from wallet 1 to wallet 2.
         let _receipts = wallet_1
-            .transfer(&wallet_2.address(), 2, Default::default())
+            .transfer(
+                &wallet_2.address(),
+                2,
+                Default::default(),
+                TxParameters::default(),
+            )
             .await
             .unwrap();
 
