@@ -1,6 +1,7 @@
 #[cfg(feature = "fuel-core")]
 use fuel_core::service::{Config, FuelService};
 use fuel_gql_client::client::schema::coin::Coin;
+use fuel_gql_client::client::types::TransactionResponse;
 use fuel_gql_client::client::{FuelClient, PageDirection, PaginationRequest};
 use fuel_tx::Receipt;
 use fuel_tx::{Address, AssetId, Input, Output, Transaction};
@@ -10,6 +11,7 @@ use std::net::SocketAddr;
 
 use fuel_vm::prelude::Opcode;
 use fuels_core::errors::Error;
+use fuels_core::parameters::TxParameters;
 use thiserror::Error;
 
 /// An error involving a signature.
@@ -105,15 +107,20 @@ impl Provider {
     }
 
     /// Craft a transaction used to transfer funds between two addresses.
-    pub fn build_transfer_tx(&self, inputs: &[Input], outputs: &[Output]) -> Transaction {
+    pub fn build_transfer_tx(
+        &self,
+        inputs: &[Input],
+        outputs: &[Output],
+        params: TxParameters,
+    ) -> Transaction {
         // This script contains a single Opcode that returns immediately (RET)
         // since all this transaction does is move Inputs and Outputs around.
         let script = Opcode::RET(REG_ONE).to_bytes().to_vec();
         Transaction::Script {
-            gas_price: 0,
-            gas_limit: 1_000_000,
-            byte_price: 0,
-            maturity: 0,
+            gas_price: params.gas_price,
+            gas_limit: params.gas_limit,
+            byte_price: params.byte_price,
+            maturity: params.maturity,
             receipts_root: Default::default(),
             script,
             script_data: vec![],
@@ -124,6 +131,11 @@ impl Provider {
         }
     }
 
+    /// Get transaction by id.
+    pub async fn get_transaction_by_id(&self, tx_id: &str) -> io::Result<TransactionResponse> {
+        Ok(self.client.transaction(tx_id).await.unwrap().unwrap())
+    }
+
     // @todo
     // - Get transaction(s)
     // - Get block(s)
